# AlPyVision
> AlPyVision (**Al**bion **Py**thon **Vision**) is a package that provides API-like functionality and acts as a
> middleman between the [Python OpenCV](https://docs.opencv.org/4.x/index.html) library and the 
> [Albion Online](https://albiononline.com/en/news) game client.

## Disclaimer
> Cheating or botting is not allowed in Albion Online. This package is for learning-purposes only, such as getting
> into the field of computer vision or artificial intelligence. Do not use this package to violate the rules.

## Props
> The ground-lying idea and much of the basic architecture is heavily inspired by the
> [OpenCV Object Detection in Games YouTube series](https://www.youtube.com/c/LearnCodeByGaming/playlists)
> made by [Learn Code By Gaming](https://learncodebygaming.com/). Ben produces tutorials of exceptionally high quality,
> covering the whole stretch from the basic 'What is a Python class?' to Canny Edge Detection with stunningly precise
> explanations. You should definitely check out his content, if you want to learn more about Object Detection and
> Python. Thank you, Ben!